==> harmony-css-plugin-0.1.1.tgz: package/index.js <==
class harmonyCssPlugin {
  constructor(options) {
    this.options = options;
    this.htmlFilesSet = []
  }

  apply(compiler) {
    compiler.plugin('compilation', (compilation) => {
      compilation.plugin('html-webpack-plugin-after-html-processing', (htmlPluginData, callback) => {
        const css = `<style>
  html, body {
    overflow-y: hidden;
  }
  .weex-root {
    height: 100% !important;
    overflow-y: hidden;
  }
  .weex-scroller-wrapper {
    flex: 1 !important;
  }
  .weex-list-wrapper {
    flex: 1 !important;
  }
  .weex-scroller-horizontal .weex-scroller-inner {
    flex: 1;
    justify-content: space-around;
  }
  .weex-loading {
    /* position: static !important;
    bottom: 0 !important; */
  }
  input {
    outline: none;
  }
  .weex-scroller-parent {
    height: 100%;
  }
  ${this.options ? this.options.cssContent : ''}
</style>`;

        htmlPluginData.html = htmlPluginData.html.replace('</head>', `${css}\n</head>`)

        const script = `<script>
  // 获取根元素
  const root = document.documentElement;

  // 设置CSS变量
  function setCSSVariable(variable, value) {
    root.style.setProperty(variable, value);
  }

  if ($midea_harmony_native) {
    var device_display = $midea_harmony_native.getHarmoryDeviceDisplay();
    if (device_display && device_display.densityPixels) {
      setCSSVariable('--harmory-density-pixels', device_display.densityPixels);
      setCSSVariable('--harmory-device-width', device_display.deviceWidth);
    }
  }
</script>
`
        htmlPluginData.html = htmlPluginData.html.replace('</head>', `${script}\n</head>`)
        
        callback(null, htmlPluginData);

      })
    })
  }
}

module.exports = harmonyCssPlugin;

==> harmony-css-plugin-0.1.2.tgz: package/index.js <==
class harmonyCssPlugin {
  constructor(options) {
    this.options = options;
    this.htmlFilesSet = []
  }

  apply(compiler) {
    compiler.plugin('compilation', (compilation) => {
      compilation.plugin('html-webpack-plugin-after-html-processing', (htmlPluginData, callback) => {
        const css = `<style>
  html, body {
    overflow-y: hidden;
  }
  .weex-root {
    height: 100% !important;
    overflow-y: hidden;
  }
  .weex-scroller-wrapper {
    flex: 1 !important;
  }
  .weex-list-wrapper {
    flex: 1 !important;
  }
  .weex-scroller-horizontal .weex-scroller-inner {
    flex: 1;
    justify-content: inherit;
  }
  .weex-loading {
    /* position: static !important;
    bottom: 0 !important; */
  }
  input {
    outline: none;
  }
  .weex-scroller-parent {
    height: 100%;
  }
  ${this.options ? this.options.cssContent : ''}
</style>`;

        htmlPluginData.html = htmlPluginData.html.replace('</head>', `${css}\n</head>`)

        const script = `<script>
  // 获取根元素
  const root = document.documentElement;

  // 设置CSS变量
  function setCSSVariable(variable, value) {
    root.style.setProperty(variable, value);
  }

  if ($midea_harmony_native) {
    var device_display = $midea_harmony_native.getHarmoryDeviceDisplay();
    if (device_display && device_display.densityPixels) {
      setCSSVariable('--harmory-density-pixels', device_display.densityPixels);
      setCSSVariable('--harmory-device-width', device_display.deviceWidth);
    }
  }
</script>
`
        htmlPluginData.html = htmlPluginData.html.replace('</head>', `${script}\n</head>`)
        
        callback(null, htmlPluginData);

      })
    })
  }
}

module.exports = harmonyCssPlugin;
